==> enterprisemodules-pg_config-0.5.0.tar.gz: enterprisemodules-pg_config-0.5.0/README.md <==
[![Enterprise Modules](https://raw.githubusercontent.com/enterprisemodules/public_images/master/banner1.jpg)](https://www.enterprisemodules.com)

#### Table of Contents

1. [Overview](#overview)
2. [License](#license)
3. [Description - What the module does and why it is useful](#description)
4. [Setup](#setup)
  * [Requirements](#requirements)
  * [Installing the pg_config module](#installing-the-pg_config-module)
5. [Usage - Configuration options and additional functionality](#usage)
6. [Reference - An under-the-hood peek at what the module is doing and how](#reference)
7. [Limitations - OS compatibility, etc.](#limitations)

## Overview

On the Puppet forge there are already some modules available that can help you install the postgres software on your system. Most of these modules, however, are missing facilities for you to create and configure databases.

The [pg_config]() module is the missing link. This module extends the puppet language so that Puppt knows about Postgres and the things there are to manage inside of a Postgres database.  

The module support Postgres 10,11,12,13 and also the beta of Postgres 14.

## License

This is a commercially licensed module. But you can use the module on VirtualBox based development systems for **FREE**. When used on **real** systems a license is required.

You can license our modules in multiple ways. Our basic licensing model requires a subscription per node. But [contact](https://www.enterprisemodules.com/company/contact/) us for details.

Check the [License](https://forge.puppet.com/enterprisemodules/pg_config/license) for details.

## Description

- Create, manage and drop Postgres databases ([pg_database](https://www.enterprisemodules.com//docs/pg_config/pg_database.html))
- Manage the parameter setting of a Postgres database ([pg_parameter](https://www.enterprisemodules.com//docs/pg_config/pg_parameter))
- Create, manage and drop Postgres users and roles ([pg_role](https://www.enterprisemodules.com//docs/pg_config/pg_role.html))
- Create, manage and drop Postgres tablespaces ([pg_tablespaces](https://www.enterprisemodules.com//docs/pg_config/pg_tablespace.html))
- Create, update, manage and drop Postgres schema definitions ([pg_schema_definition](https://www.enterprisemodules.com//docs/pg_config/pg_schema_definition.html))
- Create, update, manage and drop (configuration) records in a Postgres table. ([pg_record](https://www.enterprisemodules.com//docs/pg_config/pg_record.html))
- Create your own custom facts based on Postgres database content
- An easy way to execute arbitrary SQL scripts with `unless` and `only_if` inhibitors to facilitate idempotence. ([pg_exec](https://www.enterprisemodules.com//docs/pg_config/pg_exec.html))

Check [the documentation here](https://www.enterprisemodules.com/docs/pg_config/description.html)

## Setup

### Requirements

The [`pg_config`](https://www.enterprisemodules.com/shop/products/puppet-pg_config-module?taxon_id=14) module requires:

- Puppet module [`enterprisemodules-easy_type`](https://forge.puppet.com/enterprisemodules/easy_type) installed.
- Puppet version 6.0 or higher. Can be Puppet Enterprise or Puppet Open Source
- A valid Enterprise Modules license for usage.
- Runs on most Linux systems.

### Installing the pg_config module

To install these modules, you can use a `Puppetfile`

```
mod 'enterprisemodules/pg_config'               ,'x.x.x'
```

Then use the `librarian-puppet` or `r10K` to install the software.

You can also install the software using the `puppet module`  command:

```
puppet module install enterprisemodules-pg_config
```

## Usage

Building a total Postgre setup requires quite some work. To help you, we have built [some examples](https://github.com/enterprisemodules/simple_pg_demo). The repo contains a demonstration of a simple database installation and configuration. 

## Reference

Here you can find some more information regarding this puppet module:

- [The `pg_config` documentation](https://www.enterprisemodules.com/docs/pg_config/description.html)


## Limitations

This module runs on most Linux versions. It requires a puppet version 5 or higher. The module does **NOT** run on windows systems.

==> enterprisemodules-pg_config-0.11.0.tar.gz: enterprisemodules-pg_config-0.11.0/README.md <==
[![Enterprise Modules](https://raw.githubusercontent.com/enterprisemodules/public_images/master/banner1.jpg)](https://www.enterprisemodules.com)

#### Table of Contents

- [Overview](#overview)
- [License](#license)
- [Description](#description)
- [Setup](#setup)
  - [Requirements](#requirements)
  - [Installing the pg_config module](#installing-the-pg_config-module)
- [Usage](#usage)
- [Reference](#reference)
- [Limitations](#limitations)

## Overview

On the Puppet forge there are already some modules available that can help you install the postgres software on your system. Most of these modules, however, are missing facilities for you to create and configure databases.

The [pg_config](https://www.enterprisemodules.com/shop/products/puppet-postgres-config) module is the missing link. This module extends the puppet language so that Puppet knows about Postgres and the things there are to manage inside of a Postgres database.  

The module support Postgres 10,11,12,13,14 and 15

The module supports multiple instances of Postgres on a system.

## License

This is a commercially licensed module. But you can use the module on VirtualBox based development systems for **FREE**. When used on **real** systems a license is required.

You can license our modules in multiple ways. Our basic licensing model requires a subscription per node. But [contact](https://www.enterprisemodules.com/company/contact/) us for details.

Check the [License](https://forge.puppet.com/enterprisemodules/pg_config/license) for details.

## Description

- Create, manage and drop Postgres databases ([pg_database](https://www.enterprisemodules.com//docs/pg_config/pg_database.html))
- Manage the parameter setting of a Postgres database ([pg_parameter](https://www.enterprisemodules.com//docs/pg_config/pg_parameter))
- Create, manage and drop Postgres users and roles ([pg_role](https://www.enterprisemodules.com//docs/pg_config/pg_role.html))
- Create, manage and drop Postgres tablespaces ([pg_tablespaces](https://www.enterprisemodules.com//docs/pg_config/pg_tablespace.html))
- Create, update, manage and drop Postgres schema definitions ([pg_schema_definition](https://www.enterprisemodules.com//docs/pg_config/pg_schema_definition.html))
- Create, update, manage and drop (configuration) records in a Postgres table. ([pg_record](https://www.enterprisemodules.com//docs/pg_config/pg_record.html))
- Create your own custom facts based on Postgres database content
- An easy way to execute arbitrary SQL scripts with `unless` and `only_if` inhibitors to facilitate idempotence. ([pg_exec](https://www.enterprisemodules.com//docs/pg_config/pg_exec.html))

Check [the documentation here](https://www.enterprisemodules.com/docs/pg_config/description.html)

## Setup

### Requirements

The [`pg_config`](https://www.enterprisemodules.com/shop/products/puppet-pg_config-module?taxon_id=14) module requires:

- Puppet module [`enterprisemodules-easy_type`](https://forge.puppet.com/enterprisemodules/easy_type) installed.
- Puppet version 6.0 or higher. Can be Puppet Enterprise or Puppet Open Source
- A valid Enterprise Modules license for usage.
- Runs on most Linux systems.

### Installing the pg_config module

To install these modules, you can use a `Puppetfile`

```
mod 'enterprisemodules/pg_config'               ,'x.x.x'
```

Then use the `librarian-puppet` or `r10K` to install the software.

You can also install the software using the `puppet module`  command:

```
puppet module install enterprisemodules-pg_config
```

## Usage

Building a total Postgre setup requires quite some work. To help you, we have built [some examples](https://github.com/enterprisemodules/simple_pg_demo). The repo contains a demonstration of a simple database installation and configuration. 

## Reference

Here you can find some more information regarding this puppet module:

- [The `pg_config` documentation](https://www.enterprisemodules.com/docs/pg_config/description.html)


## Limitations

This module runs on most Linux versions. It requires a puppet version 5 or higher. The module does **NOT** run on windows systems.
